## 🚀 Features

### Initial release

First release of the Security Lake Tools CLI with support for creating AWS Security Lake custom sources for OCSF event classes. Includes automatic IAM role creation, AWS account auto-detection, and SSO token expiration handling.

*By @mavam.*

## 🔧 Changes

### Remove Python 3.10 and 3.11 support

The minimum Python version is now 3.12. The CI test matrix now covers Python 3.12 and 3.13.

*By @mavam and @claude.*
